==> ejc-purchasingmanagement-impl-3.0.0-20220714.104004-159-sources.jar: com/ejianc/business/purchasingmanagement/bean/TransporterpaymentdetailEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 运输商付款单明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_transporterpaymentdetail")
public class TransporterpaymentdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="transporterpayment_id")
    private Long transporterpaymentId; // 运输商付款单主键
    @TableField(value="transportationacceptance_id")
    private Long transportationacceptanceId; // 运费验收主键
    @TableField(value="acceptance_date")
    private Date acceptanceDate; // 日期
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="amount")
    private BigDecimal amount; // 金额
    @TableField(value="uncollected_money")
    private BigDecimal uncollectedMoney; // 未付金额
    @TableField(value="received_money")
    private BigDecimal receivedMoney; // 本单已付金额
    @TableField(value="other_received_money")
    private BigDecimal otherReceivedMoney; // 其他单已付金额
    @TableField(value="receivable_money")
    private BigDecimal receivableMoney; // 应付金额
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="distribution_money")
    private BigDecimal distributionMoney; // 分配金额
    @TableField(value="bill_code")
    private String billCode; // 运输商付款单单据号
    @TableField(value="shipping_type")
    private Integer shippingType; //运费类型   0，自动 1,手动

    public Integer getShippingType() {
        return shippingType;
    }

    public void setShippingType(Integer shippingType) {
        this.shippingType = shippingType;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }

    public Long getTransporterpaymentId() {
        return transporterpaymentId;
    }

    public void setTransporterpaymentId(Long transporterpaymentId) {
        this.transporterpaymentId = transporterpaymentId;
    }
    public Long getTransportationacceptanceId() {
        return transportationacceptanceId;
    }

    public void setTransportationacceptanceId(Long transportationacceptanceId) {
        this.transportationacceptanceId = transportationacceptanceId;
    }
    public Date getAcceptanceDate() {
        return acceptanceDate;
    }

    public void setAcceptanceDate(Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public BigDecimal getUncollectedMoney() {
        return uncollectedMoney;
    }

    public void setUncollectedMoney(BigDecimal uncollectedMoney) {
        this.uncollectedMoney = uncollectedMoney;
    }
    public BigDecimal getReceivedMoney() {
        return receivedMoney;
    }

    public void setReceivedMoney(BigDecimal receivedMoney) {
        this.receivedMoney = receivedMoney;
    }
    public BigDecimal getOtherReceivedMoney() {
        return otherReceivedMoney;
    }

    public void setOtherReceivedMoney(BigDecimal otherReceivedMoney) {
        this.otherReceivedMoney = otherReceivedMoney;
    }
    public BigDecimal getReceivableMoney() {
        return receivableMoney;
    }

    public void setReceivableMoney(BigDecimal receivableMoney) {
        this.receivableMoney = receivableMoney;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20221017.091328-230-sources.jar: com/ejianc/business/purchasingmanagement/bean/TransporterpaymentdetailEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 运输商付款单明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_transporterpaymentdetail")
public class TransporterpaymentdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="transporterpayment_id")
    private Long transporterpaymentId; // 运输商付款单主键
    @TableField(value="transportationacceptance_id")
    private Long transportationacceptanceId; // 运费验收主键
    @TableField(value="material_id")
    private Long materialId; // 原材料id
    @TableField(value="material_name")
    private String materialName; // 原材料名称
    @TableField(value="acceptance_date")
    private Date acceptanceDate; // 日期
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="amount")
    private BigDecimal amount; // 金额
    @TableField(value="uncollected_money")
    private BigDecimal uncollectedMoney; // 未付金额
    @TableField(value="received_money")
    private BigDecimal receivedMoney; // 本单已付金额
    @TableField(value="other_received_money")
    private BigDecimal otherReceivedMoney; // 其他单已付金额
    @TableField(value="receivable_money")
    private BigDecimal receivableMoney; // 应付金额
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="distribution_money")
    private BigDecimal distributionMoney; // 分配金额
    @TableField(value="bill_code")
    private String billCode; // 运输商付款单单据号
    @TableField(value="shipping_type")
    private Integer shippingType; //运费类型   0，自动 1,手动

    public Integer getShippingType() {
        return shippingType;
    }

    public void setShippingType(Integer shippingType) {
        this.shippingType = shippingType;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }

    public Long getTransporterpaymentId() {
        return transporterpaymentId;
    }

    public void setTransporterpaymentId(Long transporterpaymentId) {
        this.transporterpaymentId = transporterpaymentId;
    }
    public Long getTransportationacceptanceId() {
        return transportationacceptanceId;
    }

    public void setTransportationacceptanceId(Long transportationacceptanceId) {
        this.transportationacceptanceId = transportationacceptanceId;
    }
    public Date getAcceptanceDate() {
        return acceptanceDate;
    }

    public void setAcceptanceDate(Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public BigDecimal getUncollectedMoney() {
        return uncollectedMoney;
    }

    public void setUncollectedMoney(BigDecimal uncollectedMoney) {
        this.uncollectedMoney = uncollectedMoney;
    }
    public BigDecimal getReceivedMoney() {
        return receivedMoney;
    }

    public void setReceivedMoney(BigDecimal receivedMoney) {
        this.receivedMoney = receivedMoney;
    }
    public BigDecimal getOtherReceivedMoney() {
        return otherReceivedMoney;
    }

    public void setOtherReceivedMoney(BigDecimal otherReceivedMoney) {
        this.otherReceivedMoney = otherReceivedMoney;
    }
    public BigDecimal getReceivableMoney() {
        return receivableMoney;
    }

    public void setReceivableMoney(BigDecimal receivableMoney) {
        this.receivableMoney = receivableMoney;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
}
